Class: Google::Cloud::SecretManager::V1::EnableManagedRotationRequest::CloudSQLSingleUserCredentials

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/secretmanager/v1/service.rb

Overview

These are the credentials required for Cloud SQL DB for Single user Managed Rotation.

Instance Attribute Summary collapse

Instance Attribute Details

#instance_id::String

Returns Required. Instance ID of the Cloud SQL instance.

Returns:

  • (::String)

    Required. Instance ID of the Cloud SQL instance.



141
142
143
144
# File 'proto_docs/google/cloud/secretmanager/v1/service.rb', line 141

class CloudSQLSingleUserCredentials
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#password::String

Returns Optional. Password of the Cloud SQL instance. If this is not provided, a random password will be generated.

Returns:

  • (::String)

    Optional. Password of the Cloud SQL instance. If this is not provided, a random password will be generated.



141
142
143
144
# File 'proto_docs/google/cloud/secretmanager/v1/service.rb', line 141

class CloudSQLSingleUserCredentials
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#username::String

Returns Required. Username of the Cloud SQL instance.

Returns:

  • (::String)

    Required. Username of the Cloud SQL instance.



141
142
143
144
# File 'proto_docs/google/cloud/secretmanager/v1/service.rb', line 141

class CloudSQLSingleUserCredentials
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end