Class: Google::Cloud::SecretManager::V1::Replication
- Inherits:
-
Object
- Object
- Google::Cloud::SecretManager::V1::Replication
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/secretmanager/v1/resources.rb
Overview
A policy that defines the replication and encryption configuration of data.
Defined Under Namespace
Classes: Automatic, UserManaged
Instance Attribute Summary collapse
-
#automatic ⇒ ::Google::Cloud::SecretManager::V1::Replication::Automatic
The Secret will automatically be replicated without any restrictions.
-
#user_managed ⇒ ::Google::Cloud::SecretManager::V1::Replication::UserManaged
The Secret will only be replicated into the locations specified.
Instance Attribute Details
#automatic ⇒ ::Google::Cloud::SecretManager::V1::Replication::Automatic
Returns The Secret will automatically be replicated without any restrictions.
Note: The following fields are mutually exclusive: automatic, user_managed. If a field in that set is populated, all other fields in the set will automatically be cleared.
312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 |
# File 'proto_docs/google/cloud/secretmanager/v1/resources.rb', line 312 class Replication include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # A replication policy that replicates the # {::Google::Cloud::SecretManager::V1::Secret Secret} payload without any # restrictions. # @!attribute [rw] customer_managed_encryption # @return [::Google::Cloud::SecretManager::V1::CustomerManagedEncryption] # Optional. The customer-managed encryption configuration of the # {::Google::Cloud::SecretManager::V1::Secret Secret}. If no configuration is # provided, Google-managed default encryption is used. # # Updates to the {::Google::Cloud::SecretManager::V1::Secret Secret} encryption # configuration only apply to # {::Google::Cloud::SecretManager::V1::SecretVersion SecretVersions} added # afterwards. They do not apply retroactively to existing # {::Google::Cloud::SecretManager::V1::SecretVersion SecretVersions}. class Automatic include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # A replication policy that replicates the # {::Google::Cloud::SecretManager::V1::Secret Secret} payload into the locations # specified in # {::Google::Cloud::SecretManager::V1::Replication::UserManaged#replicas Replication.UserManaged.replicas} # @!attribute [rw] replicas # @return [::Array<::Google::Cloud::SecretManager::V1::Replication::UserManaged::Replica>] # Required. The list of Replicas for this # {::Google::Cloud::SecretManager::V1::Secret Secret}. # # Cannot be empty. class UserManaged include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Represents a Replica for this # {::Google::Cloud::SecretManager::V1::Secret Secret}. # @!attribute [rw] location # @return [::String] # The canonical IDs of the location to replicate data. # For example: `"us-east1"`. # @!attribute [rw] customer_managed_encryption # @return [::Google::Cloud::SecretManager::V1::CustomerManagedEncryption] # Optional. The customer-managed encryption configuration of the # [User-Managed Replica][Replication.UserManaged.Replica]. If no # configuration is provided, Google-managed default encryption is used. # # Updates to the {::Google::Cloud::SecretManager::V1::Secret Secret} # encryption configuration only apply to # {::Google::Cloud::SecretManager::V1::SecretVersion SecretVersions} added # afterwards. They do not apply retroactively to existing # {::Google::Cloud::SecretManager::V1::SecretVersion SecretVersions}. class Replica include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end end |
#user_managed ⇒ ::Google::Cloud::SecretManager::V1::Replication::UserManaged
Returns The Secret will only be replicated into the locations specified.
Note: The following fields are mutually exclusive: user_managed, automatic. If a field in that set is populated, all other fields in the set will automatically be cleared.
312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 |
# File 'proto_docs/google/cloud/secretmanager/v1/resources.rb', line 312 class Replication include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # A replication policy that replicates the # {::Google::Cloud::SecretManager::V1::Secret Secret} payload without any # restrictions. # @!attribute [rw] customer_managed_encryption # @return [::Google::Cloud::SecretManager::V1::CustomerManagedEncryption] # Optional. The customer-managed encryption configuration of the # {::Google::Cloud::SecretManager::V1::Secret Secret}. If no configuration is # provided, Google-managed default encryption is used. # # Updates to the {::Google::Cloud::SecretManager::V1::Secret Secret} encryption # configuration only apply to # {::Google::Cloud::SecretManager::V1::SecretVersion SecretVersions} added # afterwards. They do not apply retroactively to existing # {::Google::Cloud::SecretManager::V1::SecretVersion SecretVersions}. class Automatic include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # A replication policy that replicates the # {::Google::Cloud::SecretManager::V1::Secret Secret} payload into the locations # specified in # {::Google::Cloud::SecretManager::V1::Replication::UserManaged#replicas Replication.UserManaged.replicas} # @!attribute [rw] replicas # @return [::Array<::Google::Cloud::SecretManager::V1::Replication::UserManaged::Replica>] # Required. The list of Replicas for this # {::Google::Cloud::SecretManager::V1::Secret Secret}. # # Cannot be empty. class UserManaged include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Represents a Replica for this # {::Google::Cloud::SecretManager::V1::Secret Secret}. # @!attribute [rw] location # @return [::String] # The canonical IDs of the location to replicate data. # For example: `"us-east1"`. # @!attribute [rw] customer_managed_encryption # @return [::Google::Cloud::SecretManager::V1::CustomerManagedEncryption] # Optional. The customer-managed encryption configuration of the # [User-Managed Replica][Replication.UserManaged.Replica]. If no # configuration is provided, Google-managed default encryption is used. # # Updates to the {::Google::Cloud::SecretManager::V1::Secret Secret} # encryption configuration only apply to # {::Google::Cloud::SecretManager::V1::SecretVersion SecretVersions} added # afterwards. They do not apply retroactively to existing # {::Google::Cloud::SecretManager::V1::SecretVersion SecretVersions}. class Replica include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end end |