Class: Google::Cloud::SecretManager::V1::Rotation::ManagedRotationStatus

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/secretmanager/v1/resources.rb

Overview

Represents the status of a managed rotation.

This is applicable only to Typed Secrets. It indicates whether the rotation is active and any errors that may have occurred during the asynchronous managed rotation.

Defined Under Namespace

Modules: State

Instance Attribute Summary collapse

Instance Attribute Details

#error::Google::Rpc::Status (readonly)

Returns Output only. Displays customer-facing issues that occurred during an asynchronous managed rotation. For example, if there are some permission errors.

Returns:

  • (::Google::Rpc::Status)

    Output only. Displays customer-facing issues that occurred during an asynchronous managed rotation. For example, if there are some permission errors.



547
548
549
550
551
552
553
554
555
556
557
558
559
560
561
562
# File 'proto_docs/google/cloud/secretmanager/v1/resources.rb', line 547

class ManagedRotationStatus
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # This defines the various states in which the managed rotation can be.
  module State
    # Not specified. This value is unused and invalid.
    STATE_UNSPECIFIED = 0

    # Indicates that the Managed rotation is ACTIVE.
    ACTIVE = 1

    # Indicates that the Managed rotation is INACTIVE.
    INACTIVE = 2
  end
end

#state::Google::Cloud::SecretManager::V1::Rotation::ManagedRotationStatus::State (readonly)

Returns Output only. Indicates whether the Managed Rotation is active or not.

Returns:



547
548
549
550
551
552
553
554
555
556
557
558
559
560
561
562
# File 'proto_docs/google/cloud/secretmanager/v1/resources.rb', line 547

class ManagedRotationStatus
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # This defines the various states in which the managed rotation can be.
  module State
    # Not specified. This value is unused and invalid.
    STATE_UNSPECIFIED = 0

    # Indicates that the Managed rotation is ACTIVE.
    ACTIVE = 1

    # Indicates that the Managed rotation is INACTIVE.
    INACTIVE = 2
  end
end