Class: Google::Cloud::SecretManager::V1::EnableManagedRotationRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/secretmanager/v1/service.rb

Overview

Defined Under Namespace

Classes: CloudSQLSingleUserCredentials

Instance Attribute Summary collapse

Instance Attribute Details

#cloud_sql_single_user_credentials::Google::Cloud::SecretManager::V1::EnableManagedRotationRequest::CloudSQLSingleUserCredentials

Returns Credentials required for Cloud SQL DB for Single user Managed Rotation.

Returns:



125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
# File 'proto_docs/google/cloud/secretmanager/v1/service.rb', line 125

class EnableManagedRotationRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # These are the credentials required for Cloud SQL DB for Single user
  # Managed Rotation.
  # @!attribute [rw] instance_id
  #   @return [::String]
  #     Required. Instance ID of the Cloud SQL instance.
  # @!attribute [rw] username
  #   @return [::String]
  #     Required. Username of the Cloud SQL instance.
  # @!attribute [rw] password
  #   @return [::String]
  #     Optional. Password of the Cloud SQL instance. If this is not provided,
  #     a random password will be generated.
  class CloudSQLSingleUserCredentials
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#parent::String

Returns Required. The resource name of the Secret to associate with the SecretVersion in the format projects/*/secrets/* or projects/*/locations/*/secrets/*.

Returns:

  • (::String)

    Required. The resource name of the Secret to associate with the SecretVersion in the format projects/*/secrets/* or projects/*/locations/*/secrets/*.



125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
# File 'proto_docs/google/cloud/secretmanager/v1/service.rb', line 125

class EnableManagedRotationRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # These are the credentials required for Cloud SQL DB for Single user
  # Managed Rotation.
  # @!attribute [rw] instance_id
  #   @return [::String]
  #     Required. Instance ID of the Cloud SQL instance.
  # @!attribute [rw] username
  #   @return [::String]
  #     Required. Username of the Cloud SQL instance.
  # @!attribute [rw] password
  #   @return [::String]
  #     Optional. Password of the Cloud SQL instance. If this is not provided,
  #     a random password will be generated.
  class CloudSQLSingleUserCredentials
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end