Class: Google::Cloud::SecretManager::V1::ReplicationStatus
- Inherits:
-
Object
- Object
- Google::Cloud::SecretManager::V1::ReplicationStatus
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/secretmanager/v1/resources.rb
Overview
The replication status of a SecretVersion.
Defined Under Namespace
Classes: AutomaticStatus, UserManagedStatus
Instance Attribute Summary collapse
-
#automatic ⇒ ::Google::Cloud::SecretManager::V1::ReplicationStatus::AutomaticStatus
Describes the replication status of a SecretVersion with automatic replication.
-
#user_managed ⇒ ::Google::Cloud::SecretManager::V1::ReplicationStatus::UserManagedStatus
Describes the replication status of a SecretVersion with user-managed replication.
Instance Attribute Details
#automatic ⇒ ::Google::Cloud::SecretManager::V1::ReplicationStatus::AutomaticStatus
Returns Describes the replication status of a SecretVersion with automatic replication.
Only populated if the parent Secret has an automatic replication policy.
Note: The following fields are mutually exclusive: automatic, user_managed. If a field in that set is populated, all other fields in the set will automatically be cleared.
419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 468 469 |
# File 'proto_docs/google/cloud/secretmanager/v1/resources.rb', line 419 class ReplicationStatus include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The replication status of a # {::Google::Cloud::SecretManager::V1::SecretVersion SecretVersion} using # automatic replication. # # Only populated if the parent {::Google::Cloud::SecretManager::V1::Secret Secret} # has an automatic replication policy. # @!attribute [r] customer_managed_encryption # @return [::Google::Cloud::SecretManager::V1::CustomerManagedEncryptionStatus] # Output only. The customer-managed encryption status of the # {::Google::Cloud::SecretManager::V1::SecretVersion SecretVersion}. Only # populated if customer-managed encryption is used. class AutomaticStatus include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The replication status of a # {::Google::Cloud::SecretManager::V1::SecretVersion SecretVersion} using # user-managed replication. # # Only populated if the parent {::Google::Cloud::SecretManager::V1::Secret Secret} # has a user-managed replication policy. # @!attribute [r] replicas # @return [::Array<::Google::Cloud::SecretManager::V1::ReplicationStatus::UserManagedStatus::ReplicaStatus>] # Output only. The list of replica statuses for the # {::Google::Cloud::SecretManager::V1::SecretVersion SecretVersion}. class UserManagedStatus include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Describes the status of a user-managed replica for the # {::Google::Cloud::SecretManager::V1::SecretVersion SecretVersion}. # @!attribute [r] location # @return [::String] # Output only. The canonical ID of the replica location. # For example: `"us-east1"`. # @!attribute [r] customer_managed_encryption # @return [::Google::Cloud::SecretManager::V1::CustomerManagedEncryptionStatus] # Output only. The customer-managed encryption status of the # {::Google::Cloud::SecretManager::V1::SecretVersion SecretVersion}. Only # populated if customer-managed encryption is used. class ReplicaStatus include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end end |
#user_managed ⇒ ::Google::Cloud::SecretManager::V1::ReplicationStatus::UserManagedStatus
Returns Describes the replication status of a SecretVersion with user-managed replication.
Only populated if the parent Secret has a user-managed replication policy.
Note: The following fields are mutually exclusive: user_managed, automatic. If a field in that set is populated, all other fields in the set will automatically be cleared.
419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 468 469 |
# File 'proto_docs/google/cloud/secretmanager/v1/resources.rb', line 419 class ReplicationStatus include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The replication status of a # {::Google::Cloud::SecretManager::V1::SecretVersion SecretVersion} using # automatic replication. # # Only populated if the parent {::Google::Cloud::SecretManager::V1::Secret Secret} # has an automatic replication policy. # @!attribute [r] customer_managed_encryption # @return [::Google::Cloud::SecretManager::V1::CustomerManagedEncryptionStatus] # Output only. The customer-managed encryption status of the # {::Google::Cloud::SecretManager::V1::SecretVersion SecretVersion}. Only # populated if customer-managed encryption is used. class AutomaticStatus include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The replication status of a # {::Google::Cloud::SecretManager::V1::SecretVersion SecretVersion} using # user-managed replication. # # Only populated if the parent {::Google::Cloud::SecretManager::V1::Secret Secret} # has a user-managed replication policy. # @!attribute [r] replicas # @return [::Array<::Google::Cloud::SecretManager::V1::ReplicationStatus::UserManagedStatus::ReplicaStatus>] # Output only. The list of replica statuses for the # {::Google::Cloud::SecretManager::V1::SecretVersion SecretVersion}. class UserManagedStatus include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Describes the status of a user-managed replica for the # {::Google::Cloud::SecretManager::V1::SecretVersion SecretVersion}. # @!attribute [r] location # @return [::String] # Output only. The canonical ID of the replica location. # For example: `"us-east1"`. # @!attribute [r] customer_managed_encryption # @return [::Google::Cloud::SecretManager::V1::CustomerManagedEncryptionStatus] # Output only. The customer-managed encryption status of the # {::Google::Cloud::SecretManager::V1::SecretVersion SecretVersion}. Only # populated if customer-managed encryption is used. class ReplicaStatus include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end end |