Class: Google::Cloud::SecretManager::V1::Rotation
- Inherits:
-
Object
- Object
- Google::Cloud::SecretManager::V1::Rotation
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/secretmanager/v1/resources.rb
Overview
The rotation time and period for a Secret. At next_rotation_time, Secret Manager will send a Pub/Sub notification to the topics configured on the Secret. Secret.topics must be set to configure rotation.
Defined Under Namespace
Classes: ManagedRotationStatus
Instance Attribute Summary collapse
-
#managed_rotation_status ⇒ ::Google::Cloud::SecretManager::V1::Rotation::ManagedRotationStatus
readonly
Output only.
-
#next_rotation_time ⇒ ::Google::Protobuf::Timestamp
Optional.
-
#rotation_period ⇒ ::Google::Protobuf::Duration
Input only.
Instance Attribute Details
#managed_rotation_status ⇒ ::Google::Cloud::SecretManager::V1::Rotation::ManagedRotationStatus (readonly)
Returns Output only. The current status of the managed rotation. This field is only applicable to Typed Secrets. This field is set by the service and cannot be set by the user.
530 531 532 533 534 535 536 537 538 539 540 541 542 543 544 545 546 547 548 549 550 551 552 553 554 555 556 557 558 559 560 561 562 563 |
# File 'proto_docs/google/cloud/secretmanager/v1/resources.rb', line 530 class Rotation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Represents the status of a managed rotation. # # This is applicable only to Typed Secrets. It indicates whether the # rotation is active and any errors that may have occurred during the # asynchronous managed rotation. # @!attribute [r] state # @return [::Google::Cloud::SecretManager::V1::Rotation::ManagedRotationStatus::State] # Output only. Indicates whether the Managed Rotation is active or not. # @!attribute [r] error # @return [::Google::Rpc::Status] # Output only. Displays customer-facing issues that occurred during an # asynchronous managed rotation. For example, if there are some permission # errors. class ManagedRotationStatus include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # This defines the various states in which the managed rotation can be. module State # Not specified. This value is unused and invalid. STATE_UNSPECIFIED = 0 # Indicates that the Managed rotation is ACTIVE. ACTIVE = 1 # Indicates that the Managed rotation is INACTIVE. INACTIVE = 2 end end end |
#next_rotation_time ⇒ ::Google::Protobuf::Timestamp
Returns Optional. Timestamp in UTC at which the Secret is scheduled to rotate. Cannot be set to less than 300s (5 min) in the future and at most 3153600000s (100 years).
next_rotation_time MUST be set if rotation_period is set.
530 531 532 533 534 535 536 537 538 539 540 541 542 543 544 545 546 547 548 549 550 551 552 553 554 555 556 557 558 559 560 561 562 563 |
# File 'proto_docs/google/cloud/secretmanager/v1/resources.rb', line 530 class Rotation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Represents the status of a managed rotation. # # This is applicable only to Typed Secrets. It indicates whether the # rotation is active and any errors that may have occurred during the # asynchronous managed rotation. # @!attribute [r] state # @return [::Google::Cloud::SecretManager::V1::Rotation::ManagedRotationStatus::State] # Output only. Indicates whether the Managed Rotation is active or not. # @!attribute [r] error # @return [::Google::Rpc::Status] # Output only. Displays customer-facing issues that occurred during an # asynchronous managed rotation. For example, if there are some permission # errors. class ManagedRotationStatus include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # This defines the various states in which the managed rotation can be. module State # Not specified. This value is unused and invalid. STATE_UNSPECIFIED = 0 # Indicates that the Managed rotation is ACTIVE. ACTIVE = 1 # Indicates that the Managed rotation is INACTIVE. INACTIVE = 2 end end end |
#rotation_period ⇒ ::Google::Protobuf::Duration
Returns Input only. The Duration between rotation notifications. Must be in seconds and at least 3600s (1h) and at most 3153600000s (100 years).
If rotation_period is set, next_rotation_time must be set. next_rotation_time will be advanced by this period when the service automatically sends rotation notifications.
530 531 532 533 534 535 536 537 538 539 540 541 542 543 544 545 546 547 548 549 550 551 552 553 554 555 556 557 558 559 560 561 562 563 |
# File 'proto_docs/google/cloud/secretmanager/v1/resources.rb', line 530 class Rotation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Represents the status of a managed rotation. # # This is applicable only to Typed Secrets. It indicates whether the # rotation is active and any errors that may have occurred during the # asynchronous managed rotation. # @!attribute [r] state # @return [::Google::Cloud::SecretManager::V1::Rotation::ManagedRotationStatus::State] # Output only. Indicates whether the Managed Rotation is active or not. # @!attribute [r] error # @return [::Google::Rpc::Status] # Output only. Displays customer-facing issues that occurred during an # asynchronous managed rotation. For example, if there are some permission # errors. class ManagedRotationStatus include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # This defines the various states in which the managed rotation can be. module State # Not specified. This value is unused and invalid. STATE_UNSPECIFIED = 0 # Indicates that the Managed rotation is ACTIVE. ACTIVE = 1 # Indicates that the Managed rotation is INACTIVE. INACTIVE = 2 end end end |