Class: Google::Cloud::SecretManager::V1::SecretVersion
- Inherits:
-
Object
- Object
- Google::Cloud::SecretManager::V1::SecretVersion
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/secretmanager/v1/resources.rb
Overview
A secret version resource in the Secret Manager API.
Defined Under Namespace
Modules: State
Instance Attribute Summary collapse
-
#client_specified_payload_checksum ⇒ ::Boolean
readonly
Output only.
-
#create_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
-
#customer_managed_encryption ⇒ ::Google::Cloud::SecretManager::V1::CustomerManagedEncryptionStatus
readonly
Output only.
-
#destroy_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
-
#etag ⇒ ::String
readonly
Output only.
-
#name ⇒ ::String
readonly
Output only.
-
#replication_status ⇒ ::Google::Cloud::SecretManager::V1::ReplicationStatus
The replication status of the SecretVersion.
-
#scheduled_destroy_time ⇒ ::Google::Protobuf::Timestamp
readonly
Optional.
-
#state ⇒ ::Google::Cloud::SecretManager::V1::SecretVersion::State
readonly
Output only.
Instance Attribute Details
#client_specified_payload_checksum ⇒ ::Boolean (readonly)
Returns Output only. True if payload checksum specified in SecretPayload object has been received by SecretManagerService on SecretManagerService.AddSecretVersion.
270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 |
# File 'proto_docs/google/cloud/secretmanager/v1/resources.rb', line 270 class SecretVersion include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The state of a # {::Google::Cloud::SecretManager::V1::SecretVersion SecretVersion}, indicating if # it can be accessed. module State # Not specified. This value is unused and invalid. STATE_UNSPECIFIED = 0 # The {::Google::Cloud::SecretManager::V1::SecretVersion SecretVersion} may be # accessed. ENABLED = 1 # The {::Google::Cloud::SecretManager::V1::SecretVersion SecretVersion} may not # be accessed, but the secret data is still available and can be placed # back into the # {::Google::Cloud::SecretManager::V1::SecretVersion::State::ENABLED ENABLED} # state. DISABLED = 2 # The {::Google::Cloud::SecretManager::V1::SecretVersion SecretVersion} is # destroyed and the secret data is no longer stored. A version may not # leave this state once entered. DESTROYED = 3 end end |
#create_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. The time at which the SecretVersion was created.
270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 |
# File 'proto_docs/google/cloud/secretmanager/v1/resources.rb', line 270 class SecretVersion include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The state of a # {::Google::Cloud::SecretManager::V1::SecretVersion SecretVersion}, indicating if # it can be accessed. module State # Not specified. This value is unused and invalid. STATE_UNSPECIFIED = 0 # The {::Google::Cloud::SecretManager::V1::SecretVersion SecretVersion} may be # accessed. ENABLED = 1 # The {::Google::Cloud::SecretManager::V1::SecretVersion SecretVersion} may not # be accessed, but the secret data is still available and can be placed # back into the # {::Google::Cloud::SecretManager::V1::SecretVersion::State::ENABLED ENABLED} # state. DISABLED = 2 # The {::Google::Cloud::SecretManager::V1::SecretVersion SecretVersion} is # destroyed and the secret data is no longer stored. A version may not # leave this state once entered. DESTROYED = 3 end end |
#customer_managed_encryption ⇒ ::Google::Cloud::SecretManager::V1::CustomerManagedEncryptionStatus (readonly)
Returns Output only. The customer-managed encryption status of the SecretVersion. Only populated if customer-managed encryption is used and Secret is a regionalized secret.
270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 |
# File 'proto_docs/google/cloud/secretmanager/v1/resources.rb', line 270 class SecretVersion include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The state of a # {::Google::Cloud::SecretManager::V1::SecretVersion SecretVersion}, indicating if # it can be accessed. module State # Not specified. This value is unused and invalid. STATE_UNSPECIFIED = 0 # The {::Google::Cloud::SecretManager::V1::SecretVersion SecretVersion} may be # accessed. ENABLED = 1 # The {::Google::Cloud::SecretManager::V1::SecretVersion SecretVersion} may not # be accessed, but the secret data is still available and can be placed # back into the # {::Google::Cloud::SecretManager::V1::SecretVersion::State::ENABLED ENABLED} # state. DISABLED = 2 # The {::Google::Cloud::SecretManager::V1::SecretVersion SecretVersion} is # destroyed and the secret data is no longer stored. A version may not # leave this state once entered. DESTROYED = 3 end end |
#destroy_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. The time this SecretVersion was destroyed. Only present if state is DESTROYED.
270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 |
# File 'proto_docs/google/cloud/secretmanager/v1/resources.rb', line 270 class SecretVersion include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The state of a # {::Google::Cloud::SecretManager::V1::SecretVersion SecretVersion}, indicating if # it can be accessed. module State # Not specified. This value is unused and invalid. STATE_UNSPECIFIED = 0 # The {::Google::Cloud::SecretManager::V1::SecretVersion SecretVersion} may be # accessed. ENABLED = 1 # The {::Google::Cloud::SecretManager::V1::SecretVersion SecretVersion} may not # be accessed, but the secret data is still available and can be placed # back into the # {::Google::Cloud::SecretManager::V1::SecretVersion::State::ENABLED ENABLED} # state. DISABLED = 2 # The {::Google::Cloud::SecretManager::V1::SecretVersion SecretVersion} is # destroyed and the secret data is no longer stored. A version may not # leave this state once entered. DESTROYED = 3 end end |
#etag ⇒ ::String (readonly)
Returns Output only. Etag of the currently stored SecretVersion.
270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 |
# File 'proto_docs/google/cloud/secretmanager/v1/resources.rb', line 270 class SecretVersion include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The state of a # {::Google::Cloud::SecretManager::V1::SecretVersion SecretVersion}, indicating if # it can be accessed. module State # Not specified. This value is unused and invalid. STATE_UNSPECIFIED = 0 # The {::Google::Cloud::SecretManager::V1::SecretVersion SecretVersion} may be # accessed. ENABLED = 1 # The {::Google::Cloud::SecretManager::V1::SecretVersion SecretVersion} may not # be accessed, but the secret data is still available and can be placed # back into the # {::Google::Cloud::SecretManager::V1::SecretVersion::State::ENABLED ENABLED} # state. DISABLED = 2 # The {::Google::Cloud::SecretManager::V1::SecretVersion SecretVersion} is # destroyed and the secret data is no longer stored. A version may not # leave this state once entered. DESTROYED = 3 end end |
#name ⇒ ::String (readonly)
Returns Output only. The resource name of the
SecretVersion in the format
projects/*/secrets/*/versions/*.
SecretVersion IDs in a Secret start at 1 and are incremented for each subsequent version of the secret.
270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 |
# File 'proto_docs/google/cloud/secretmanager/v1/resources.rb', line 270 class SecretVersion include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The state of a # {::Google::Cloud::SecretManager::V1::SecretVersion SecretVersion}, indicating if # it can be accessed. module State # Not specified. This value is unused and invalid. STATE_UNSPECIFIED = 0 # The {::Google::Cloud::SecretManager::V1::SecretVersion SecretVersion} may be # accessed. ENABLED = 1 # The {::Google::Cloud::SecretManager::V1::SecretVersion SecretVersion} may not # be accessed, but the secret data is still available and can be placed # back into the # {::Google::Cloud::SecretManager::V1::SecretVersion::State::ENABLED ENABLED} # state. DISABLED = 2 # The {::Google::Cloud::SecretManager::V1::SecretVersion SecretVersion} is # destroyed and the secret data is no longer stored. A version may not # leave this state once entered. DESTROYED = 3 end end |
#replication_status ⇒ ::Google::Cloud::SecretManager::V1::ReplicationStatus
Returns The replication status of the SecretVersion.
270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 |
# File 'proto_docs/google/cloud/secretmanager/v1/resources.rb', line 270 class SecretVersion include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The state of a # {::Google::Cloud::SecretManager::V1::SecretVersion SecretVersion}, indicating if # it can be accessed. module State # Not specified. This value is unused and invalid. STATE_UNSPECIFIED = 0 # The {::Google::Cloud::SecretManager::V1::SecretVersion SecretVersion} may be # accessed. ENABLED = 1 # The {::Google::Cloud::SecretManager::V1::SecretVersion SecretVersion} may not # be accessed, but the secret data is still available and can be placed # back into the # {::Google::Cloud::SecretManager::V1::SecretVersion::State::ENABLED ENABLED} # state. DISABLED = 2 # The {::Google::Cloud::SecretManager::V1::SecretVersion SecretVersion} is # destroyed and the secret data is no longer stored. A version may not # leave this state once entered. DESTROYED = 3 end end |
#scheduled_destroy_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Optional. Output only. Scheduled destroy time for secret version. This is a part of the Delayed secret version destroy feature. For a Secret with a valid version destroy TTL, when a secert version is destroyed, version is moved to disabled state and it is scheduled for destruction Version is destroyed only after the scheduled_destroy_time.
270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 |
# File 'proto_docs/google/cloud/secretmanager/v1/resources.rb', line 270 class SecretVersion include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The state of a # {::Google::Cloud::SecretManager::V1::SecretVersion SecretVersion}, indicating if # it can be accessed. module State # Not specified. This value is unused and invalid. STATE_UNSPECIFIED = 0 # The {::Google::Cloud::SecretManager::V1::SecretVersion SecretVersion} may be # accessed. ENABLED = 1 # The {::Google::Cloud::SecretManager::V1::SecretVersion SecretVersion} may not # be accessed, but the secret data is still available and can be placed # back into the # {::Google::Cloud::SecretManager::V1::SecretVersion::State::ENABLED ENABLED} # state. DISABLED = 2 # The {::Google::Cloud::SecretManager::V1::SecretVersion SecretVersion} is # destroyed and the secret data is no longer stored. A version may not # leave this state once entered. DESTROYED = 3 end end |
#state ⇒ ::Google::Cloud::SecretManager::V1::SecretVersion::State (readonly)
Returns Output only. The current state of the SecretVersion.
270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 |
# File 'proto_docs/google/cloud/secretmanager/v1/resources.rb', line 270 class SecretVersion include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The state of a # {::Google::Cloud::SecretManager::V1::SecretVersion SecretVersion}, indicating if # it can be accessed. module State # Not specified. This value is unused and invalid. STATE_UNSPECIFIED = 0 # The {::Google::Cloud::SecretManager::V1::SecretVersion SecretVersion} may be # accessed. ENABLED = 1 # The {::Google::Cloud::SecretManager::V1::SecretVersion SecretVersion} may not # be accessed, but the secret data is still available and can be placed # back into the # {::Google::Cloud::SecretManager::V1::SecretVersion::State::ENABLED ENABLED} # state. DISABLED = 2 # The {::Google::Cloud::SecretManager::V1::SecretVersion SecretVersion} is # destroyed and the secret data is no longer stored. A version may not # leave this state once entered. DESTROYED = 3 end end |